@@ -67,7 +67,7 @@ SettingsBase::SettingsBase( QWidget * parent )
     // Initalise the window so we don't flicker
     initToolBar();
     // We can now launch the delayed loading safely
-    QTimer::singleShot(0, this, SLOT(initApplication()));
+    QTimer::singleShot(0, this, &SettingsBase::initApplication);
 }
 
 SettingsBase::~SettingsBase()
@@ -137,6 +137,8 @@ void SettingsBase::initToolBar()
     configureAction->setText( i18n("Configure") );
     // Help after it
     initHelpMenu();
+    configureAction->setIcon(QIcon::fromTheme("application-menu"));
+
     // Then a spacer so the search line-edit is kept separate
     spacerAction = new QWidgetAction( this );
     spacerAction->setDefaultWidget(spacerWidget);
@@ -155,12 +157,12 @@ void SettingsBase::initToolBar()
     helpActionMenu->setMenu( dynamic_cast<QMenu*>( factory()->container("help", this) ) );
     setMinimumSize(620,430);
     toolBar()->setMovable(false); // We don't allow any changes
-    changeToolBar( BaseMode::Search | BaseMode::Configure | BaseMode::Quit );
+    changeToolBar( BaseMode::Search | BaseMode::Configure );
 }
 
 void SettingsBase::initHelpMenu()
 {
-    helpActionMenu = new KActionMenu( QIcon::fromTheme("system-help"), i18n("Help"), this );
+    helpActionMenu = new KActionMenu( QIcon::fromTheme("help-contents"), i18n("Help"), this );
     helpActionMenu->setDelayed( false );
     actionCollection()->addAction( "help_toolbar_menu", helpActionMenu );
     // Add the custom actions
